# NOTE: This package is fully arched due to dependency sensitivity.
# Please do not remove archfulness on Requires/Provides.

%define debug_package %{nil}

%global min_dnf_ver 4.0
%global min_pykickstart_ver 2.25

Name:          livecd-tools
Summary:       Tools for building live CDs
Version:       31.0
Release:       %mkrel 4
License:       GPLv2
Group:         System/Base
URL:           https://github.com/livecd-tools/livecd-tools
Source0:       https://releases.pagure.org/%{name}/%{name}-%{version}.tar.gz

BuildRequires: python3-devel
# pod2man comes from perl
BuildRequires: perl

Requires:      python3-imgcreate%{?_isa} = %{version}-%{release}

%ifarch %{ix86} x86_64
Requires:      livecd-iso-to-mediums = %{version}-%{release}
%endif

%description
Tools for generating live CDs on Fedora based systems including
derived distributions such as RHEL, CentOS and others. See
https://fedoraproject.org/wiki/FedoraLiveCD for more details.

This package is patched to support building live images on
Mageia systems.

%package -n python-imgcreate-sysdeps
Summary:       Common system dependencies for python-imgcreate
Group:         System/Base
Requires:      coreutils
Requires:      xorriso
Requires:      isomd5sum
Requires:      parted
Requires:      util-linux
Requires:      dosfstools
Requires:      e2fsprogs
%ifarch %{ix86} x86_64 aarch64
Requires:      mkefiboot
%endif
Requires:      rsync
%ifarch %{ix86} x86_64 ppc ppc64
Requires:      hfsplus-tools
%endif
%ifarch %{ix86} x86_64
Requires:      syslinux
%endif
%ifarch ppc
Requires:      yaboot
%endif
Requires:      dumpet
Requires:      sssd-client
Requires:      cryptsetup
Requires:      squashfs-tools
Requires:      policycoreutils

%description -n python-imgcreate-sysdeps
This package describes the common system dependencies for
python-imgcreate.

%package -n python3-imgcreate
Summary:       Python 3 modules for building system images
Group:         Development/Python
%{?python_provide:%python_provide python3-imgcreate}
Requires:      python-imgcreate-sysdeps%{?_isa} = %{version}-%{release}
Requires:      python3-parted
Requires:      python3-dnf >= %{min_dnf_ver}
Requires:      python3-kickstart >= %{min_pykickstart_ver}
Requires:      python3-six
Requires:      libselinux-python3
Requires:      python3-dbus

%description -n python3-imgcreate
Python 3 modules that can be used for building images for things
like live image or appliances.


%ifarch %{ix86} x86_64
%package -n livecd-iso-to-mediums
Summary:       Tools for installing ISOs to different mediums
Group:         System/Base
Requires:      python-imgcreate-sysdeps%{?_isa} = %{version}-%{release}
Obsoletes:     livecd-iso-to-disk < 21.2-7
Provides:      livecd-iso-to-disk = %{version}-%{release}
Requires:      extlinux
Requires:      pxelinux


%description -n livecd-iso-to-mediums
Tools for installing Live CD ISOs to different mediums
(e.g. USB sticks, hard drives, PXE boot, etc.)
%endif

%prep
%autosetup -p1 -n %{name}-%name-%{version}

%build
# Nothing to do


%install
%make_install PYTHON=python3

# Delete installed docs, we'll grab them later
rm -rf %{buildroot}%{_datadir}/doc/%{name}

%ifnarch %{ix86} x86_64
# livecd-iso-to-mediums doesn't work without syslinux
rm -rfv %{buildroot}%{_bindir}/livecd-iso-to-*
rm -rfv %{buildroot}%{_mandir}/man8/livecd-iso-to-*
%endif

%files
%license COPYING
%doc AUTHORS README HACKING
%doc config/livecd-fedora-minimal.ks
%doc config/livecd-mageia-minimal-*.ks
%{_bindir}/livecd-creator
%{_bindir}/image-creator
%{_bindir}/liveimage-mount
%{_bindir}/editliveos
%{_bindir}/mkbiarch
%{_mandir}/man8/livecd-creator.8*
%{_mandir}/man8/mkbiarch.8*


%files -n python-imgcreate-sysdeps
# No files because empty metapackage


%files -n python3-imgcreate
%license COPYING
%doc API
%{python3_sitelib}/imgcreate

%ifarch %{ix86} x86_64
%files -n livecd-iso-to-mediums
%license COPYING
%{_bindir}/livecd-iso-to-disk
%{_mandir}/man8/livecd-iso-to-disk.8*
%{_bindir}/livecd-iso-to-pxeboot
%endif


%changelog
* Wed Jul 02 2025 umeabot <umeabot> 31.0-4.mga10
+ Revision: 2242875
- Mageia 10 Mass Rebuild

* Tue Mar 04 2025 wally <wally> 31.0-3.mga10
+ Revision: 2160387
- rebuild for python3.13

* Tue Jan 28 2025 papoteur <papoteur> 31.0-2.mga10
+ Revision: 2143100
- rebuild for libgit2 1.9.0

* Mon Jan 01 2024 papoteur <papoteur> 31.0-1.mga10
+ Revision: 2025399
- new version 31.0

* Sat Mar 19 2022 umeabot <umeabot> 27.1-8.mga9
+ Revision: 1799324
- Mageia 9 Mass Rebuild

* Tue Mar 01 2022 mrambo3501 <mrambo3501> 27.1-7.mga9
+ Revision: 1787078
- rebuild for python-3.10

* Sun Mar 28 2021 daviddavid <daviddavid> 27.1-6.mga9
+ Revision: 1711474
- rebuild for python 3.9

* Sat Nov 28 2020 ngompa <ngompa> 27.1-5.mga8
+ Revision: 1649821
- Backport PR #168 to fix a compatibility issue with DNF 4.4.0+

* Sun Feb 16 2020 umeabot <umeabot> 27.1-4.mga8
+ Revision: 1533509
- Mageia 8 Mass Rebuild

* Sun Sep 22 2019 daviddavid <daviddavid> 27.1-3.mga8
+ Revision: 1444568
- rebuild for python3.8

* Mon Jul 08 2019 ngompa <ngompa> 27.1-2.mga8
+ Revision: 1419421
- Drop patch disabling EFI support now that mkefiboot is available

* Fri Apr 19 2019 ngompa <ngompa> 27.1-1.mga7
+ Revision: 1393623
- Update to 27.1

* Sun Apr 14 2019 ngompa <ngompa> 27.0-1.mga7
+ Revision: 1390119
- Rebase to v27.0
- Drop unneeded patches
- Refresh remaining patch

* Wed Jan 09 2019 daviddavid <daviddavid> 26.0-2.mga7
+ Revision: 1353098
- rebuild for new Python 3.7

* Sat Nov 24 2018 ngompa <ngompa> 26.0-1.mga7
+ Revision: 1333716
- Rebase to livecd-tools v26.0
- Drop Python 2 subpackage

* Sun Oct 28 2018 ngompa <ngompa> 25.0-4.mga7
+ Revision: 1326357
- Sync patch from Fedora to fix compat with DNF 4.0 (mga#23708)

* Sun Sep 23 2018 umeabot <umeabot> 25.0-3.mga7
+ Revision: 1299324
- Mageia 7 Mass Rebuild

* Sun Jul 01 2018 ngompa <ngompa> 25.0-2.mga7
+ Revision: 1241045
- Add patch from Fedora to fix with DNF 3 (rhbz#1595917)

* Sat Oct 21 2017 ngompa <ngompa> 25.0-1.mga7
+ Revision: 1172996
- Rebase to v25.0
- Rebase patches for v25.0
- Drop unnecessary patch for squashfs-tools, as it was fixed upstream

* Sat Aug 05 2017 pterjan <pterjan> 24.4-2.mga7
+ Revision: 1135266
- Rebuild for python 3.6

* Mon May 08 2017 ngompa <ngompa> 24.4-1.mga6
+ Revision: 1099590
- Update to 24.4

* Thu Apr 13 2017 ngompa <ngompa> 24.3-1.mga6
+ Revision: 1096507
- Update to v24.3
- Drop merged patches
- Drop merged extra sources

* Wed Mar 08 2017 ngompa <ngompa> 24.2-3.mga6
+ Revision: 1089940
- Remove nonexistent package from sample kickstarts breaking image builds

* Wed Mar 08 2017 ngompa <ngompa> 24.2-2.mga6
+ Revision: 1089936
- Fix typo in livecd-mageia-minimal-i586.ks to make sure it uses i586 repos

* Wed Mar 08 2017 ngompa <ngompa> 24.2-1.mga6
+ Revision: 1089786
- Rebase to official upstream v24.2
- Backport patch from upstream to use genisoimage instead of mkisofs
- Split out and rework patches for adapting livecd-tools to run on Mageia
- Replace example kickstarts with minimal examples

* Sat Feb 20 2016 umeabot <umeabot> 21.2-6.mga6
+ Revision: 971805
- Mageia 6 Mass Rebuild

* Tue Oct 20 2015 daviddavid <daviddavid> 21.2-5.mga6
+ Revision: 892983
- use new python macros to fix build
- add more docs to fix build with latest rpm

* Wed Oct 15 2014 umeabot <umeabot> 21.2-4.mga5
+ Revision: 744757
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 21.2-3.mga5
+ Revision: 726985
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 21.2-2.mga5
+ Revision: 681963
- Mageia 5 Mass Rebuild

* Sun Sep 07 2014 anaselli <anaselli> 21.2-1.mga5
+ Revision: 673012
- new 21.2 from mga branch
- Fixes Bug 10259 - livecd-tools new security issue CVE-2013-2069
+ umeabot <umeabot>
- Mageia 4 Mass Rebuild

* Sat Jan 12 2013 umeabot <umeabot> 17.15-2.mga3
+ Revision: 358885
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Dec 26 2012 anaselli <anaselli> 17.15-1.mga3
+ Revision: 335521
- Aligned to livecd-tools 17.15
- Fixed bug #06925: livecd-iso-to-disk should require isomd5sum

* Sun Feb 12 2012 anaselli <anaselli> 14.3-2.mga2
+ Revision: 208261
- reverted apply_patches seems not to work as expected
- kickstart file clean up
- removed mandriva system in description

* Sun Feb 12 2012 anaselli <anaselli> 14.3-1.mga2
+ Revision: 208232
- Force to use dracut configuration for initrd also
- Moved dracut.conf in /etc/dracut.conf.d/99livecd.conf
- Added hostonly=no into 99livecd.conf
- Now %%post is run as in fedora after boot_config
- imported package livecd-tools

